SystemOrganization addCategory: #'Phidget-EToys'!

PartsBin subclass: #PhdETPartsBin
	instanceVariableNames: 'controlingMorph'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETPartsBin class methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 13:17'!
thumbnailForQuad: aQuint color: aColor phidget: aPhidget
	"Answer a thumbnail for a morph obtaining as per the quintuplet provided, creating the thumbnail if necessary.  If it is created afresh, it will also be cached at this time"

	| aThumbnail aSymbol formToThumbnail labeledItem |
	aSymbol := aQuint third.
	Thumbnails at: aSymbol ifPresent: [ :thumb | ^thumb ].
	formToThumbnail := aQuint at: 5 ifAbsent: [].
	formToThumbnail ifNil: [
		labeledItem := (Smalltalk at: aQuint first) perform: aQuint second with: aPhidget.
		formToThumbnail := labeledItem imageForm: 32 backgroundColor: aColor forRectangle: labeledItem fullBounds.
		formToThumbnail replaceColor: aColor withColor: Color transparent.
	].

	aThumbnail := Thumbnail new makeThumbnailFromForm: formToThumbnail.
	self cacheThumbnail: aThumbnail forSymbol: aSymbol.
	^ aThumbnail

"PartsBin initialize"! !

!PhdETPartsBin methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 11:47'!
controlingMorph
	^ controlingMorph! !

!PhdETPartsBin methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 11:48'!
controlingMorph: aMorph
	controlingMorph := aMorph.! !

!PhdETPartsBin methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 13:18'!
listDirection: aListDirection quadList: quadList
	"Initialize the receiver to run horizontally or vertically, obtaining its elements from the list of tuples of the form:
		(<receiver> <selector> <label> <balloonHelp>)"

	| aButton aClass |
	self layoutPolicy: TableLayout new.
	self listDirection: aListDirection.
	self wrapCentering: #topLeft.
	self layoutInset: 2.
	self cellPositioning: #bottomCenter.

	aListDirection == #leftToRight
		ifTrue:
			[self vResizing: #rigid.
			self hResizing: #spaceFill.
			self wrapDirection: #topToBottom]
		ifFalse:
			[self hResizing: #rigid.
			self vResizing: #spaceFill.
			self wrapDirection: #leftToRight].
	quadList do:
		[:tuple |
			aClass := Smalltalk at: tuple first.
			aButton := IconicButton new initializeWithThumbnail: (self class thumbnailForQuad: tuple color: self color phidget: self phidget) withLabel: tuple third andColor: self color andSend: tuple second to: aClass with: self phidget.
			(tuple size > 3 and: [tuple fourth isEmptyOrNil not]) ifTrue:
				[aButton setBalloonText: tuple fourth].
 			self addMorphBack: aButton]! !

!PhdETPartsBin methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 11:58'!
phidget
	^ controlingMorph phidget! !

BorderedMorph subclass: #PhdETInterfaceKit
	instanceVariableNames: 'ifKit labelMorph Ports'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETInterfaceKit class methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 19:20'!
additionsToViewerCategories
	"Answer a list of (<categoryName> <list of category specs>) pairs that characterize the phrases this kind of morph wishes to add to various Viewer categories."
	^ #(
		(InterfaceKit (
			(slot Label 'The label of this Interface Kit.' String readWrite Player getLabel Player setLabel:)
			(slot Attached 'This is wether the an hardware Interface Kit is attached to the USB port or not.' Boolean readOnly Player getAttached unused unused)
		))
	)

! !

!PhdETInterfaceKit class methodsFor: 'as yet unclassified' stamp: 'pt 5/3/2009 19:18'!
descriptionForPartsBin
    ^ self partName:    'InterfaceKit'
        categories:     #('Phidgets')
        documentation:  'An Interface Kit'! !

!PhdETInterfaceKit methodsFor: 'as yet unclassified' stamp: 'pt 5/8/2009 12:34'!
delete
	ifKit close.
	Ports reverseDo: [ :port | port delete ].
	super delete.! !

!PhdETInterfaceKit methodsFor: 'as yet unclassified' stamp: 'pt 5/6/2009 15:54'!
getAttached
	^ ifKit attached! !

!PhdETInterfaceKit methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 09:14'!
getInput: index
	^ ifKit inputValue: index! !

!PhdETInterfaceKit methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 19:17'!
getLabel
	^ labelMorph contents! !

!PhdETInterfaceKit methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 09:14'!
getOutput: index
	^ ifKit outputValue: index! !

!PhdETInterfaceKit methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 09:15'!
getSensor: index
	^ ifKit sensorValue: index! !

!PhdETInterfaceKit methodsFor: 'as yet unclassified' stamp: 'pt 5/8/2009 11:36'!
initializeToStandAlone
	
	| aBin quads oldResizing |
	super initialize.
	self
		useRoundedCorners;
		width: 290;
		height: 75;
		color: (Color r: 0.4 g: 0.7 b: 0.4);
		setLabel: 'Interface Kit'.
	ifKit := PhdCrInterfaceKit new.
	Ports := OrderedCollection new.
	
	aBin := (PhdETPartsBin newPartsBinWithOrientation: #leftToRight from: #())
		listDirection: #leftToRight;
		wrapDirection: #topToBottom;
		color: self color lighter lighter;
		setNameTo: 'Ports';
		dropEnabled: false;
		height: self height - 20;
		top: self top + 17;
		width: self width - 6;
		left: self left + 3;
		useRoundedCorners;
		controlingMorph: self;
		yourself.

	self addMorph: aBin.

	oldResizing := aBin vResizing.
	quads := OrderedCollection new.
	PhdETIfKitInputPort addPortDescriptorQuadsTo: quads.
	PhdETIfKitOutputPort addPortDescriptorQuadsTo: quads.
	PhdETIfKitSensorPort addPortDescriptorQuadsTo: quads.
	aBin
		listDirection: #leftToRight quadList: quads;
		vResizing: oldResizing;
		layoutChanged;
		fullBounds.
	
	ifKit openAny.! !

!PhdETInterfaceKit methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 19:04'!
inputPortAvailable: portNumber
	^ ifKit inputIndexIsInRange: portNumber! !

!PhdETInterfaceKit methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 19:04'!
outputPortAvailable: portNumber
	^ ifKit outputIndexIsInRange: portNumber! !

!PhdETInterfaceKit methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 12:21'!
phidget
	^ self! !

!PhdETInterfaceKit methodsFor: 'as yet unclassified' stamp: 'pt 5/8/2009 11:32'!
registerPort: aPort
	"If a new Port was draged out of me, it registeres itself here."
	
	Ports add: aPort.! !

!PhdETInterfaceKit methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 19:04'!
sensorPortAvailable: portNumber
	^ ifKit sensorIndexIsInRange: portNumber! !

!PhdETInterfaceKit methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 19:34'!
setLabel: anObject
	labelMorph ifNil: [
		labelMorph := StringMorph new font: (TextStyle default fontAt: 2) emphasis: 1.
		self addMorph: labelMorph ].
	labelMorph
		contents: anObject asString;
		position: self center - ( labelMorph width / 2 @ ( self height / 2 - 4 ) ).
! !

!PhdETInterfaceKit methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 09:15'!
setOutput: index to: aBoolean
	^ ifKit setOutputValue: aBoolean at: index! !

!PhdETInterfaceKit methodsFor: 'as yet unclassified' stamp: 'pt 5/8/2009 11:33'!
unregisterPort: aPort
	"If a new Port was draged out of me, it registeres itself here."
	
	Ports remove: aPort ifAbsent: [].! !

BorderedMorph subclass: #PhdETPort
	instanceVariableNames: 'Phidget portNumber numberString Wire'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

PhdETPort subclass: #PhdETIfKitInputPort
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETIfKitInputPort class methodsFor: 'as yet unclassified' stamp: 'pt 5/8/2009 08:57'!
additionsToViewerCategoryInputPort
	"Answer a list of (<categoryName> <list of category specs>) pairs that characterize the phrases this kind of morph wishes to add to various Viewer categories."
	
	^ #(
		InputPort (
			(slot Value 'The value at the digital Intput port on an Interface Kit.' Boolean readOnly Player getIfKitInputValue unused unused)
			(slot PortNumber 'The index of this digital Input port.' Number readWrite Player getPortNumber Player setPortNumber:)
			(slot ShowWire 'This is wether a wire from this port to its Phidget is shown..' Boolean readWrite Player getShowWire Player setShowWire:)
		)
	)! !

!PhdETIfKitInputPort class methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 08:32'!
portDescription

	^  self
		partName:		'Digital Input'
		categories:		#('Interface Kit')
		documentation:	'An port to a digital input of an Interface Kit. This port is bound to a port of the Interface Kit hardware. With me it is possible to read wether the port returns true or false.'.! !

!PhdETIfKitInputPort methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 15:00'!
getIfKitInputValue
	^ Phidget getInput: portNumber! !

!PhdETIfKitInputPort methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 12:39'!
initialize
	super initialize.
	self color: Color red lighter.! !

!PhdETIfKitInputPort methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 19:07'!
isInRange: aNumber
	
	^ Phidget sensorPortAvailable: aNumber! !

PhdETPort subclass: #PhdETIfKitOutputPort
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETIfKitOutputPort class methodsFor: 'as yet unclassified' stamp: 'pt 5/8/2009 08:58'!
additionsToViewerCategoryOutputPort
	"Answer a list of (<categoryName> <list of category specs>) pairs that characterize the phrases this kind of morph wishes to add to various Viewer categories."

	^ #(
		OutputPort (
			(slot Value 'The value at the digital Output port on an Interface Kit.' Boolean readWrite Player getIfKitOutputValue Player setIfKitOutputValue:)
			(slot PortNumber 'The index of this digital Output port.' Number readWrite Player getPortNumber Player setPortNumber:)
			(slot ShowWire 'This is wether a wire from this port to its Phidget is shown..' Boolean readWrite Player getShowWire Player setShowWire:)
		)
	)! !

!PhdETIfKitOutputPort class methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 08:32'!
portDescription

	^  self
		partName:		'Digital Output'
		categories:		#('Interface Kit')
		documentation:	'An port to a digital output of an Interface Kit. This port is bound to a port of the Interface Kit hardware. With me it is possible to read wether the port returns true or false or set this value'.! !

!PhdETIfKitOutputPort methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 15:00'!
getIfKitOutputValue
	^ Phidget getOutput: portNumber! !

!PhdETIfKitOutputPort methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 19:14'!
initialize
	super initialize.
	self color: Color blue muchLighter.! !

!PhdETIfKitOutputPort methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 19:09'!
isInRange: aNumber
	
	^ Phidget outputPortAvailable: aNumber! !

!PhdETIfKitOutputPort methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 15:00'!
setIfKitOutputValue: aBoolean
	^ Phidget setOutput: portNumber to: aBoolean.! !

PhdETPort subclass: #PhdETIfKitSensorPort
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETIfKitSensorPort class methodsFor: 'as yet unclassified' stamp: 'pt 5/8/2009 08:59'!
additionsToViewerCategorySensorPort
	"Answer a list of (<categoryName> <list of category specs>) pairs that characterize the phrases this kind of morph wishes to add to various Viewer categories."

	^ #(
		SensorPort (
			(slot Value 'The value at the analog Sensor port on an Interface Kit.' Number readOnly Player getIfKitSensorValue unused unused)
			(slot SensorPortNumber 'The index of this analog Sensor port.' Number readWrite Player getPortNumber Player setPortNumber:)
			(slot ShowWire 'This is wether a wire from this port to its Phidget is shown..' Boolean readWrite Player getShowWire Player setShowWire:)
		)
	)! !

!PhdETIfKitSensorPort class methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 08:32'!
portDescription

	^  self
		partName:		'Analog Sensor'
		categories:		#('Interface Kit')
		documentation:	'An port to an analog sensor of an Interface Kit. This port is bound to a port of the Interface Kit hardware. With me it is possible to read which value an attached analog sensor returns. This value is between 0 and 1000.'.! !

!PhdETIfKitSensorPort methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 15:00'!
getIfKitSensorValue
	^ Phidget getSensor: portNumber! !

!PhdETIfKitSensorPort methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 12:39'!
initialize
	super initialize.
	self color: Color yellow lighter.! !

!PhdETIfKitSensorPort methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 19:09'!
isInRange: aNumber
	
	^ Phidget inputPortAvailable: aNumber! !

!PhdETPort class methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 08:17'!
addPortDescriptorQuadsTo: aList
	"analogous to addPartsDescriptorQuadsTo: aList if: aBlock from the Morph class"
	
	| info |
	info := self portDescription.
	aList add:
		{info globalReceiverSymbol.
		info nativitySelector.
		info formalName.
		info documentation.
		info sampleImageFormOrNil}.! !

!PhdETPort class methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 12:00'!
launchPartVia: aSelector label: aString phidget: aPhidget
	"Obtain a morph by sending aSelector to self, and attach it to the morphic hand.  This provides a general protocol for parts bins"

	| aMorph |
	aMorph := self perform: aSelector with: aPhidget.
	aMorph setNameTo: (ActiveWorld unusedMorphNameLike: aString).
	aMorph setProperty: #beFullyVisibleAfterDrop toValue: true.
	aMorph openInHand! !

!PhdETPort class methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 10:54'!
newStandAlone: aPhidget
	"Answer an instance capable of standing by itself as a usable morph."

	^ self basicNew initializeToStandAlone: aPhidget! !

!PhdETPort class methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 10:52'!
partName: aName categories: aList documentation: aDoc
	"Answer a DescriptionForPartsBin which will represent a launch of a new instance of my class via the #newStandAlone protocol sent to my class. Use the category-list and documentation provided"


	^ DescriptionForPartsBin new
		formalName: aName
		categoryList: aList
		documentation: aDoc
		globalReceiverSymbol: self name
		nativitySelector: #newStandAlone:! !

!PhdETPort class methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 08:18'!
portDescription

	self subclassResponsibility.
	! !

!PhdETPort methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 09:51'!
centerNumberString.
	numberString position: self center - ((numberString width / 2)@( numberString height / 2)).! !

!PhdETPort methodsFor: 'as yet unclassified' stamp: 'pt 5/8/2009 11:50'!
delete
	Wire delete.
	Phidget unregisterPort: self.
	super delete.! !

!PhdETPort methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 09:28'!
getPortNumber
	^ portNumber! !

!PhdETPort methodsFor: 'as yet unclassified' stamp: 'sp 5/9/2009 22:50'!
initialize

	super initialize.
	self useRoundedCorners.
	portNumber := 1.
	numberString := StringMorph new contents: portNumber asString.
	self
		centerNumberString;
		addMorph: numberString.
	Wire := PhdLabWire from: Phidget center to: self center.
	self currentWorld addMorphBack: Wire.! !

!PhdETPort methodsFor: 'as yet unclassified' stamp: 'pt 5/8/2009 11:34'!
initializeToStandAlone: aPhidget
	Phidget := aPhidget.
	Phidget registerPort: self.
	self initialize.
	! !

!PhdETPort methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 19:05'!
isInRange: aNumber
	"A subclass may override this, to allow changing portNumbers"
	^ false! !

!PhdETPort methodsFor: 'as yet unclassified' stamp: 'pt 5/20/2009 15:50'!
positionWire
	Wire setVertices: {Phidget center. self center}.! !

!PhdETPort methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 19:11'!
setPortNumber: aNumber
	( aNumber isInteger and: [ self isInRange: aNumber ] )
	ifTrue: [
		portNumber := aNumber.
		numberString contents: portNumber asString.
		self centerNumberString ]! !

!PhdETPort methodsFor: 'as yet unclassified' stamp: 'pt 5/8/2009 09:23'!
step
	self positionWire.! !

!PhdETPort methodsFor: 'as yet unclassified' stamp: 'pt 5/8/2009 09:22'!
stepTime
	^ 100! !

PhdETPort subclass: #PhdETServoPort
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETServoPort class methodsFor: 'as yet unclassified' stamp: 'pt 5/8/2009 08:59'!
additionsToViewerCategorySensorPort
	"Answer a list of (<categoryName> <list of category specs>) pairs that characterize the phrases this kind of morph wishes to add to various Viewer categories."

	^ #(
		ServoMotor (
			(slot Position 'The current position of the servo motor at the current port.' Number readWrite Player getServoPosition Player setServoPosition)
			(slot MaxPosition 'The max. possible position of this servo motor.' Number readOnly Player getServoMaxPosition unused unused)
			(slot MinPosition 'The max. possible position of this servo motor.' Number readOnly Player getServoMinPosition unused unused)
			(slot ServoPortNumber 'The index of this motor on the Servo board.' Number readWrite Player getPortNumber Player setPortNumber:)
			(slot ShowWire 'This is wether a wire from this port to its Phidget is shown..' Boolean readWrite Player getShowWire Player setShowWire:)
		)
	)! !

!PhdETServoPort class methodsFor: 'as yet unclassified' stamp: 'pt 5/8/2009 08:26'!
portDescription

	^  self
		partName:		'Motor Position'
		categories:		#('Servo Board')
		documentation:	'An port to a motor on the Servo board. Its value is between the minValue and maxValue.'.! !

!PhdETServoPort methodsFor: 'as yet unclassified' stamp: 'pt 5/8/2009 08:35'!
getServoMaxPosition
	^ 0! !

!PhdETServoPort methodsFor: 'as yet unclassified' stamp: 'pt 5/8/2009 08:35'!
getServoMinPosition
	^ 0! !

!PhdETServoPort methodsFor: 'as yet unclassified' stamp: 'pt 5/8/2009 08:35'!
getServoPosition
	^ 0! !

!PhdETServoPort methodsFor: 'as yet unclassified' stamp: 'pt 5/8/2009 08:25'!
initialize
	super initialize.
	self color: Color green muchLighter.! !

!PhdETServoPort methodsFor: 'as yet unclassified' stamp: 'pt 5/8/2009 08:36'!
isInRange: aNumber
	
	^ false! !
